@@ -13,7 +13,7 @@
 G_BEGIN_DECLS
 
 #define SOUP_MAJOR_VERSION (2)
-#define SOUP_MINOR_VERSION (60)
+#define SOUP_MINOR_VERSION (62)
 #define SOUP_MICRO_VERSION (3)
 
 #define SOUP_CHECK_VERSION(major, minor, micro) \
@@ -65,6 +65,7 @@ G_BEGIN_DECLS
 #define SOUP_VERSION_2_54 (G_ENCODE_VERSION (2, 54))
 #define SOUP_VERSION_2_56 (G_ENCODE_VERSION (2, 56))
 #define SOUP_VERSION_2_58 (G_ENCODE_VERSION (2, 58))
+#define SOUP_VERSION_2_62 (G_ENCODE_VERSION (2, 62))
 
 /* evaluates to the current stable version; for development cycles,
  * this means the next stable target
@@ -359,6 +360,20 @@ G_BEGIN_DECLS
 # define SOUP_AVAILABLE_IN_2_58                 _SOUP_EXTERN
 #endif
 
+#if SOUP_VERSION_MIN_REQUIRED >= SOUP_VERSION_2_62
+# define SOUP_DEPRECATED_IN_2_62                G_DEPRECATED
+# define SOUP_DEPRECATED_IN_2_62_FOR(f)         G_DEPRECATED_FOR(f)
+#else
+# define SOUP_DEPRECATED_IN_2_62
+# define SOUP_DEPRECATED_IN_2_62_FOR(f)
+#endif
+
+#if SOUP_VERSION_MAX_ALLOWED < SOUP_VERSION_2_62
+# define SOUP_AVAILABLE_IN_2_62                 G_UNAVAILABLE(2, 62) _SOUP_EXTERN
+#else
+# define SOUP_AVAILABLE_IN_2_62                 _SOUP_EXTERN
+#endif
+
 SOUP_AVAILABLE_IN_2_42
 guint    soup_get_major_version (void);
 
